@@ -5,8 +5,8 @@
  *
  * Copyright (C) 2003-2014 Mark Shelor, All Rights Reserved
  *
- * Version: 5.89
- * Sat Apr 19 05:14:48 MST 2014
+ * Version: 5.90
+ * Wed May  7 07:57:08 MST 2014
  *
  * The following macros supply placeholder values that enable the
  * sha.c module to successfully compile when 64-bit integer types
@@ -19,7 +19,6 @@
 
 #define sha_384_512		0
 #define W64			unsigned long
-#define strto64(p)		0
 #define sha512			NULL
 #define H0384			H01
 #define H0512			H01
